# Xpaper

Cross-platform library for changing desktop wallpaper

Works on windows and Linux

Supports all versions of Python


## Install

```
$ pip install xpaper
```


## Usage

```py
from xpaper import wallpaper

wallpaper.change("wallpaper.jpg)

wallpaper.get()     # "/Users/Spatocode/wallpaper.jpg"
```